.. ProtoTorch documentation master file
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

About ProtoTorch
================

.. toctree::
   :hidden:
   :maxdepth: 3
   :caption: Contents:

   self
   api

ProtoTorch is a PyTorch-based Python toolbox for bleeding-edge
research in prototype-based machine learning algorithms.

Indices
=======
* :ref:`genindex`
* :ref:`modindex`
